@@ -4,9 +4,8 @@ from .aaindex1 import *
 
 #aaindex software metadata
 __name__ = "aaindex"
-__version__ = "0.1.0"
-__description__ = "aaindex is a lightweight Python software package for accessing the data in the various AAIndex databases, \
-        which represent the physiochemical and biochemical properties of amino acids as numerical indices."
+__version__ = "1.0.3"
+__description__ = "aaindex is a lightweight Python software package for accessing the data in the various AAIndex databases, which represent the physiochemical and biochemical properties of amino acids as numerical indices."
 __author__ = 'AJ McKenna, https://github.com/amckenna41'
 __authorEmail__ = 'amckenna41@qub.ac.uk'
 __license__ = 'MIT'
